/*
 * Tapioca library
 * Copyright (C) 2005 INdT 
 * @author Abner Jose de Faria Silva <abner.silva@indt.org.br>
 * @author Andre Moreira Magalhaes <andre.magalhaes@indt.org.br>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
#ifndef __TAPIOCA_CONNECTION_H__
#define __TAPIOCA_CONNECTION_H__

#include <glib.h>
#include <glib-object.h>

#include <tapioca/core/tapioca_enums.h>
#include <tapioca/client/tapioca_session.h>
#include <tapioca/client/tapioca_presence.h>
#include <tapioca/client/tapioca_contact_list.h>

G_BEGIN_DECLS

#define TAPIOCA_TYPE_CONNECTION \
    (tapioca_connection_get_type ())
#define TAPIOCA_CONNECTION(obj) \
    (G_TYPE_CHECK_INSTANCE_CAST ((obj), TAPIOCA_TYPE_CONNECTION, TapiocaConnection))
#define TAPIOCA_CONNECTION_CLASS(klass) \
    (G_TYPE_CHECK_CLASS_CAST ((klass), TAPIOCA_TYPE_CONNECTION, TapiocaConnectionClass))
#define IS_TAPIOCA_CONNECTION(obj) \
    (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TAPIOCA_TYPE_CONNECTION))
#define IS_TAPIOCA_CONNECTION_CLASS(klass) \
    (G_TYPE_CHECK_CLASS_TYPE ((klass), TAPIOCA_TYPE_CONNECTION))
#define TAPIOCA_CONNECTION_GET_CLASS(obj) \
    (G_TYPE_INSTANCE_GET_CLASS ((obj), TAPIOCA_TYPE_CONNECTION, TapiocaConnectionClass))
#define TAPIOCA_CONNECTION_GET_PRIVATE(obj) \
    (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TAPIOCA_TYPE_CONNECTION, TapiocaConnectionPrivate))

typedef struct _TapiocaConnection        TapiocaConnection;
typedef struct _TapiocaConnectionClass   TapiocaConnectionClass;
typedef struct _TapiocaConnectionPrivate TapiocaConnectionPrivate;

struct _TapiocaConnectionClass 
{
    GObjectClass parect_class;
};

struct _TapiocaConnection 
{
    GObject parent;
    TapiocaConnectionPrivate *priv;
};

GType                  tapioca_connection_get_type         (void);

gboolean               tapioca_connection_connect          (TapiocaConnection *tp,
                                                            const gchar *id,
                                                            const GHashTable  *table);
void                   tapioca_connection_disconnect       (TapiocaConnection *tp);
TapiocaConnectionState tapioca_connection_get_state        (TapiocaConnection *tp);
TapiocaSession        *tapioca_connection_create_session   (TapiocaConnection *tp, 
		                                                    TapiocaSessionType session_type);
TapiocaPresence       *tapioca_connection_get_presence     (TapiocaConnection *tp);
TapiocaContactList    *tapioca_connection_get_contact_list (TapiocaConnection *tp);  

G_CONST_RETURN gchar  *tapioca_connection_get_id           (TapiocaConnection *tp);

G_END_DECLS

#endif
