/*
 * Tapioca library
 * Copyright (C) 2005 INdT 
 * @author Andre Moreira Magalhaes <andre.magalhaes@indt.org.br>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TAPIOCA_AUDIO_SESSION_H__
#define __TAPIOCA_AUDIO_SESSION_H__

#include <glib.h>
#include <glib-object.h>

#include <tapioca/core/tapioca_session.h>

G_BEGIN_DECLS

/* TYPE MACROS */
#define TAPIOCA_TYPE_AUDIO_SESSION \
  (tapioca_audio_session_get_type())
#define TAPIOCA_AUDIO_SESSION(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj), TAPIOCA_TYPE_AUDIO_SESSION, TapiocaAudioSession))
#define TAPIOCA_AUDIO_SESSION_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass), TAPIOCA_TYPE_AUDIO_SESSION, TapiocaAudioSessionClass))
#define TAPIOCA_IS_AUDIO_SESSION(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TAPIOCA_TYPE_AUDIO_SESSION))
#define TAPIOCA_IS_AUDIO_SESSION_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE((klass), TAPIOCA_TYPE_AUDIO_SESSION))
#define TAPIOCA_AUDIO_SESSION_GET_CLASS(obj) \
  (G_TYPE_INSTANCE_GET_CLASS ((obj), TAPIOCA_TYPE_AUDIO_SESSION, TapiocaAudioSessionClass))
#define TAPIOCA_AUDIO_SESSION_GET_PRIVATE(obj) \
  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TAPIOCA_TYPE_AUDIO_SESSION, TapiocaAudioSessionPrivate))

typedef struct _TapiocaAudioSession        TapiocaAudioSession;
typedef struct _TapiocaAudioSessionClass   TapiocaAudioSessionClass;
typedef struct _TapiocaAudioSessionPrivate TapiocaAudioSessionPrivate;

struct _TapiocaAudioSessionClass {
    TapiocaSessionClass parent_class;

    /* callbacks */
    gboolean (* accept)                      (TapiocaAudioSession *tas,
                                              GError **error);
    gboolean (* reject)                      (TapiocaAudioSession *tas,
                                              GError **error);
    gboolean (* set_local_capabilities)      (TapiocaAudioSession *tas,
                                              const gchar *local_capabilities,
                                              GError **error);
    gboolean (* get_capabilities)            (TapiocaAudioSession *tas,
                                              gchar **local_capabilities,
                                              gchar **remote_capabilities,
                                              GError **error);
    gboolean (* add_local_candidate)         (TapiocaAudioSession *tas, 
                                              const gchar *name,
                                              const gchar *protocol,
                                              const gchar *ip,
                                              guint port,
                                              gdouble preference,
                                              const gchar *username,
                                              const gchar *password,
                                              const gchar *type,
                                              guint generation,
                                              GError **error);
};

struct _TapiocaAudioSession {
    TapiocaSession parent;

    /* private */
    TapiocaAudioSessionPrivate *priv;
};

GType    tapioca_audio_session_get_type                           (void);

void     tapioca_audio_session_signal_remote_capabilities_updated (TapiocaAudioSession *tas,
                                                                   const gchar *remote_capabilities);
void     tapioca_audio_session_signal_remote_candidate_added      (TapiocaAudioSession *tas, 
                                                                   const gchar *name,
                                                                   const gchar *protocol,
                                                                   const gchar *ip,
                                                                   guint port,
                                                                   gdouble preference,
                                                                   const gchar *username,
                                                                   const gchar *password,
                                                                   const gchar *type,
                                                                   guint generation);

G_END_DECLS

#endif
