/*
 * Tapioca library
 * Copyright (C) 2005 INdT 
 * @author Luiz Augusto von Dentz <luiz.dentz@indt.org.br>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TAPIOCA_CONTACT_LIST_H__
#define __TAPIOCA_CONTACT_LIST_H__

#include <glib-object.h>

G_BEGIN_DECLS

#define TAPIOCA_TYPE_CONTACT_LIST              (tapioca_contact_list_get_type ())
#define TAPIOCA_CONTACT_LIST(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), TAPIOCA_TYPE_CONTACT_LIST, TapiocaContactList))
#define TAPIOCA_CONTACT_LIST_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), TAPIOCA_TYPE_CONTACT_LIST, TapiocaContactListClass))
#define IS_TAPIOCA_CONTACT_LIST(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), TAPIOCA_TYPE_CONTACT_LIST))
#define IS_TAPIOCA_CONTACT_LIST_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), TAPIOCA_TYPE_CONTACT_LIST))
#define TAPIOCA_CONTACT_LIST_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), TAPIOCA_TYPE_CONTACT_LIST, TapiocaContactListClass))
#define TAPIOCA_CONTACT_LIST_GET_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TAPIOCA_TYPE_CONTACT_LIST, TapiocaContactListPrivate))

typedef struct _TapiocaContact            TapiocaContact;
typedef struct _TapiocaContactList        TapiocaContactList;
typedef struct _TapiocaContactListClass   TapiocaContactListClass;
typedef struct _TapiocaContactListPrivate TapiocaContactListPrivate;

struct _TapiocaContact
{
    gchar *address;
    gchar *alias;
    gchar *group;
    guint type;
};

struct _TapiocaContactListClass
{
    GObjectClass parent;

    /* callbacks */
    void        (* request_contacts)
                                    (TapiocaContactList *tcl);
    void        (* request_contact_info)
                                    (TapiocaContactList *tcl,
                                     const gchar *address);
    void        (* add_contact)     (TapiocaContactList *tcl,
                                     const gchar *address,
                                     const gchar *alias,
                                     const gchar *group);
    void        (* remove_contact)  (TapiocaContactList *tcl,
                                     const gchar *address);
    void        (* authorize_contact)    
                                    (TapiocaContactList *tcl,
                                     const gchar *address,
                                     const gchar *group);
    void        (* deny_contact)    (TapiocaContactList *tcl,
                                     const gchar *address);
};

struct _TapiocaContactList
{
    GObject parent;

    TapiocaContactListPrivate *priv;
};

GType    tapioca_contact_list_get_type                         (void);

void     tapioca_contact_list_signal_contact_authorized        (TapiocaContactList *tcl,
                                                                const gchar *address);
void     tapioca_contact_list_signal_contact_denied            (TapiocaContactList *tcl,
                                                                const gchar *address);
void     tapioca_contact_list_signal_authorization_requested   (TapiocaContactList *tcl,
                                                                const gchar *address);
void     tapioca_contact_list_signal_contacts_retrieved        (TapiocaContactList *tcl,
                                                                const gchar *address,
                                                                const gchar *alias,
                                                                const gchar *group,
                                                                guint subscription_type);
void     tapioca_contact_list_signal_contact_info_retrieved    (TapiocaContactList *tcl,
                                                                const gchar *address,
                                                                GHashTable **info);
G_END_DECLS

#endif
