/*
 * Tapioca library
 * Copyright (C) 2005 INdT 
 * @author Luiz Augusto von Dentz <luiz.dentz@indt.org.br>
 * @author Andre Moreira Magalhaes <andre.magalhaes@indt.org.br>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TAPIOCA_PRESENCE_H__
#define __TAPIOCA_PRESENCE_H__

#include <glib-object.h>

G_BEGIN_DECLS

#define TAPIOCA_TYPE_PRESENCE              (tapioca_presence_get_type ())
#define TAPIOCA_PRESENCE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), TAPIOCA_TYPE_PRESENCE, TapiocaPresence))
#define TAPIOCA_PRESENCE_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), TAPIOCA_TYPE_PRESENCE, TapiocaPresenceClass))
#define IS_TAPIOCA_PRESENCE(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), TAPIOCA_TYPE_PRESENCE))
#define IS_TAPIOCA_PRESENCE_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), TAPIOCA_TYPE_PRESENCE))
#define TAPIOCA_PRESENCE_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), TAPIOCA_TYPE_PRESENCE, TapiocaPresenceClass))
#define TAPIOCA_PRESENCE_GET_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TAPIOCA_TYPE_PRESENCE, TapiocaPresencePrivate))

typedef struct _TapiocaPresence        TapiocaPresence;
typedef struct _TapiocaPresenceClass   TapiocaPresenceClass;
typedef struct _TapiocaPresencePrivate TapiocaPresencePrivate;

struct _TapiocaPresenceClass
{
    GObjectClass parent;

    /* callbacks */
    gboolean (* subscribe)              (TapiocaPresence *tp,
                                         guint status,
                                         const gchar *status_desc,
                                         GError **error);
    gboolean (* unsubscribe)            (TapiocaPresence *tp,     
                                         GError **error);
    void     (* get_supported_statuses) (TapiocaPresence *tp,
                                         GArray **statuses);
    gboolean (* set_status)             (TapiocaPresence *tp,
                                         guint status, 
                                         const gchar *status_desc,
                                         GError **error);
    void     (* request_status)         (TapiocaPresence *tp,
                                         gchar **list);
    void     (* release_status)         (TapiocaPresence *tp,
                                         gchar **list);
};

struct _TapiocaPresence
{
    GObject parent;

    TapiocaPresencePrivate *priv;
};

GType    tapioca_presence_get_type              (void);
       
gboolean tapioca_presence_in_watch_list         (TapiocaPresence *tp,
                                                 const gchar *contact);

void     tapioca_presence_signal_subscribed     (TapiocaPresence *tp);
void     tapioca_presence_signal_unsubscribed   (TapiocaPresence *tp);
void     tapioca_presence_signal_status_updated (TapiocaPresence *tp,
                                                 const gchar *contact,
                                                 guint status, 
                                                 const gchar *status_desc,
                                                 gboolean phone_capability);

G_END_DECLS

#endif
