/*
 * Tapioca library
 * Copyright (C) 2005 INdT 
 * @author Andre Moreira Magalhaes <andre.magalhaes@indt.org.br>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TAPIOCA_SESSION_H__
#define __TAPIOCA_SESSION_H__

#include <glib.h>
#include <glib-object.h>

G_BEGIN_DECLS

/* TYPE MACROS */
#define TAPIOCA_TYPE_SESSION \
  (tapioca_session_get_type())
#define TAPIOCA_SESSION(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj), TAPIOCA_TYPE_SESSION, TapiocaSession))
#define TAPIOCA_SESSION_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass), TAPIOCA_TYPE_SESSION, TapiocaSessionClass))
#define TAPIOCA_IS_SESSION(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TAPIOCA_TYPE_SESSION))
#define TAPIOCA_IS_SESSION_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_TYPE((klass), TAPIOCA_TYPE_SESSION))
#define TAPIOCA_SESSION_GET_CLASS(obj) \
  (G_TYPE_INSTANCE_GET_CLASS ((obj), TAPIOCA_TYPE_SESSION, TapiocaSessionClass))
#define TAPIOCA_SESSION_GET_PRIVATE(obj) \
  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TAPIOCA_TYPE_SESSION, TapiocaSessionPrivate))

typedef struct _TapiocaSession        TapiocaSession;
typedef struct _TapiocaSessionClass   TapiocaSessionClass;
typedef struct _TapiocaSessionPrivate TapiocaSessionPrivate;

struct _TapiocaSessionClass {
    GObjectClass parent_class;

    /* callbacks */
    gboolean (* initiate)        (TapiocaSession *ts,
                                  GError **error);
    void     (* close)           (TapiocaSession *ts);
    gboolean (* add_members)     (TapiocaSession *ts,
                                  const gchar **ids,
                                  GError **error);
    gboolean (* remove_members)  (TapiocaSession *ts,
                                  const gchar **ids,
                                  GError **error);
};

struct _TapiocaSession {
    GObject parent;

    guint session_type;
    guint state;
    GList *members;
    
    /* private */
    TapiocaSessionPrivate *priv;
};

GType    tapioca_session_get_type                (void);

void     tapioca_session_change_state            (TapiocaSession *ts,
                                                  guint state);
void     tapioca_session_signal_member_added     (TapiocaSession *ts,
                                                  const gchar *id);
void     tapioca_session_signal_member_removed   (TapiocaSession *ts,
                                                  const gchar *id);
void     tapioca_session_signal_add_member_error (TapiocaSession *ts,
                                                  guint error_code,
                                                  const gchar *id);
void     tapioca_session_signal_error            (TapiocaSession *ts,
                                                  guint error_code);

G_END_DECLS

#endif
